<?php

/* Check whether the Modified WordPress Plugin API is installed */
if ( !function_exists( 'wp_hook_sniff_plugin_api' ) )
	define( 'WP_HOOK_SNIFF_API', False );


// Finish including all necessary files
require_once( WP_HOOK_PLUGIN_DIR . '/wp-hook-sniff-admin.php' );


/**
 * Determine set WordPress Hook Sniffer options
 * 
 * Grabs the stored set options for WordPress Hook Sniffer from 
 * the wp_options table (wp_x_options in multisite) for later use.
 */

global $wp_hook_sniffer_options_set;
$wp_hook_sniffer_options_set = apply_filters( 'wp_hook_sniff_set_options', get_option( 'wp_hook_sniffer_options' ) );


/**
 * wp_hook_sniff_output_hook_info()
 * 
 * Outputs ...
 *
 * Uses data assembled by action_filter_backtrace(), a special
 * function added to the WP Plugin API exclusively for the
 * WP Hook Sniffer Plugin.
 * 
 * @since 0.1
 */
function wp_hook_sniff_output_hook_info() {
	global $wp_hook_sniffer_options_set, $wp_actions, $wp_filter, $wp_hook_sniff_action_firing_sequence, $wp_hook_sniff_filter_firing_sequence, $wp_hook_sniff_functions_added_array, $wp_hook_sniff_functions_removed_array;
	
	/* Check to see if we should be outputting anything */
	
	// If the Modified WordPress Plugin API file is not installed, exit
	if( WP_HOOK_SNIFF_API == False )
		return;	
	
	// If WordPress Hook Sniffer is disabled, exit
	if( $wp_hook_sniffer_options_set[ 'enabled' ] == 0 )
		return;
	
	// If WordPress Hook Sniffer is enabled, but no output options were selected, exit
	if( $wp_hook_sniffer_options_set[ 'enabled' ] == 1 && empty( $wp_hook_sniffer_options_set[ 'output' ] ) )
		return;
	
	do_action( 'wp_hook_sniff_before_output_hook_info' );
	
	// Otherwise, we're good to go! Output selected results

	if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
		// send output to text file
		
		/* Set the filepath and filename for the WP Hook Sniff text report */
		$wp_hook_sniff_path_file = WP_HOOK_PLUGIN_DIR . "/hook-sniff-report/wp-hook-sniff.txt";
		
		/* create the header for the output report */
		$wp_hook_sniff_report_header = "WordPress Hook Sniffer Report \nReport Version: 0.1 \nReport Date: " . Date( DATE_RFC822 ) . "\n";
		$fh = fopen( $wp_hook_sniff_path_file, "wt" ) or die( "can't open file" );
		fwrite( $fh, $wp_hook_sniff_report_header );
		fclose( $fh );

	}
	
	/**
	 * Added Functions Output
	 *
	 * Output the special WP Hook Sniffer array that holds, in the order
	 * in which they were encountered during code execution, all add_action
	 * calls and add_filter calls
	 */
	if( $wp_hook_sniffer_options_set[ 'output' ][ 'added_functions' ] == true ) {	
		
		if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
			$wp_hook_sniffer_functions_array_element = "\n_________________________________________\n" . __( 'Added Functions:', WP_HOOK_PLUGIN_NAME ) . "\n\n";
		} else {
			$wp_hook_sniffer_functions_array_element = "<br />_________________________________________<br /><strong>" . __( 'Added Functions:', WP_HOOK_PLUGIN_NAME ) . "</strong><br /><br />";
		}
			
		/* Iterate through the array of all added action and filter functions
		 * This array is a multidimensional array with each primary element 
		 * holding an array that contains the details about each added function
		 */
		foreach( (array)$wp_hook_sniff_functions_added_array as $key => $value ) {
			
			/* Output is placed into a string variable to make it easier
			 * to either echo to screen or send to a text file
			 */
			
			$wp_hook_sniffer_functions_array_element .= "{$value["sequence"]}: {$value["action"]}( '{$value["event"]}', '{$value["function"]}'";
			
			if( !empty( $value["priority"] ) ) {
				$wp_hook_sniffer_functions_array_element .= ", " . $value["priority"];
			}
			
			if( !empty( $value["args"] ) ) {
				$wp_hook_sniffer_functions_array_element .= ", " . $value["args"] . " )";
			} else {
				$wp_hook_sniffer_functions_array_element .= " )"; 
			}
			
			$wp_hook_sniffer_functions_array_element .= " Called from: " . $value["file"] . " | line #: " . $value["line"] . " --> Time Added: " . $value["time"];
			
			if( $wp_hook_sniffer_options_set[ 'screen' ] == 1 ) {
				// add a linebreak for screen output
				$wp_hook_sniffer_functions_array_element .= "<br />";
			}
			
			if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
				// send output to text file

				$wp_hook_sniffer_functions_array_element .= "\n";
				$fh = fopen( $wp_hook_sniff_path_file, "at" ) or die( "can't open file" );
				fwrite( $fh, $wp_hook_sniffer_functions_array_element );
				fclose( $fh );
			
			} else /* send output to screen */ {
				echo $wp_hook_sniffer_functions_array_element;
			}
			
			// reset variable for next element content
			$wp_hook_sniffer_functions_array_element = "";
		}
	}
	
		/* For those wondering what just happened, here's the above array
		* split out into separate lines just for screen output
		*/
		
		/*
		foreach( (array)$wp_hook_sniff_functions_added_array as $key => $value ) {
			echo $value["sequence"] . ": ";
			echo $value["action"] . "( '";
			echo $value["event"] . "', '";
			echo $value["function"] . "'";
			
			if( !empty( $value["priority"] ) ) {
				echo ", " . $value["priority"];
			}
			
			if( !empty( $value["args"] ) ) {
				echo ", " . $value["args"] . " )";
			} else {
				echo " )"; 
			}
			
			echo " Called from: " . $value["file"];
			echo " | line #: " . $value["line"];
			echo " --> Time Added: " . $value["time"] . "<br />";
		}
		*/
	
	
	/**
	 * Removed Functions Output
	 *
	 * Output the special WP Hook Sniffer array that holds, in the order
	 * in which they were encountered during code execution, all remove_action
	 * calls and remove_filter calls
	 */
	 if( $wp_hook_sniffer_options_set[ 'output' ][ 'removed_functions' ] == true ) {
	
		if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
			$wp_hook_sniffer_functions_array_element = "\n_________________________________________\n" . __( 'Removed Functions:', WP_HOOK_PLUGIN_NAME ) . "\n\n";
		} else {
			$wp_hook_sniffer_functions_array_element = "<br />_________________________________________<br /><strong>" . __( 'Removed Functions:', WP_HOOK_PLUGIN_NAME ) . "</strong><br /><br />";
		}
		
		/* Iterate through the array of all removed action and filter functions
		 * This array is a multidimensional array with each primary element 
		 * holding an array that contains the details about each removed function
		 */
		foreach( (array)$wp_hook_sniff_functions_removed_array as $key => $value ) {
			
			$wp_hook_sniffer_functions_array_element .= "{$value["sequence"]}: {$value["action"]}( '{$value["event"]}', '{$value["function"]}'";
			
			if( !empty( $value["priority"] ) ) {
				$wp_hook_sniffer_functions_array_element .= ", " . $value["priority"];
			}
			
			if( !empty( $value["args"] ) ) {
				$wp_hook_sniffer_functions_array_element .= ", " . $value["args"] . " )";
			} else {
				$wp_hook_sniffer_functions_array_element .= " )"; 
			}
			
			$wp_hook_sniffer_functions_array_element .= " Called from: " . $value["file"] . " | line #: " . $value["line"] . " --> Time Removed: " . $value["time"];
			
			if( $wp_hook_sniffer_options_set[ 'screen' ] == 1 ) {
				// add a linebreak for screen output
				$wp_hook_sniffer_functions_array_element .= "<br />";
			}
			
			if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
				// send output to text file

				$wp_hook_sniffer_functions_array_element .= "\n";
				$fh = fopen( $wp_hook_sniff_path_file, "at" ) or die( "can't open file" );
				fwrite( $fh, $wp_hook_sniffer_functions_array_element );
				fclose( $fh );
			
			} else /* send output to screen */ {
				echo $wp_hook_sniffer_functions_array_element;
			}
			
			// reset variable for next element content
			$wp_hook_sniffer_functions_array_element = "";
		}
	}
	
	
	/**
	 * Action and Filter Function Array Output
	 *
	 * Output the contents of the $wp_filter array, the array that holds
	 * all of the added action and filter functions and is used by the do_action
	 * and apply_filters functions
	 */
	if( $wp_hook_sniffer_options_set[ 'output' ][ 'filter_array' ] == true ) {
		
		if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
			// send output to text file
			$wp_hook_sniffer_wp_filter_array = "\n_________________________________________\n" . __( 'Action and Filter Function Array:', WP_HOOK_PLUGIN_NAME ) . "\n\n";
		
			$wp_hook_sniffer_wp_filter_array .= print_r( $wp_filter, true );
			$fh = fopen( $wp_hook_sniff_path_file, "at" ) or die( "can't open file" );
			fwrite( $fh, $wp_hook_sniffer_wp_filter_array );
			fclose( $fh );
		} else {
			$wp_hook_sniffer_wp_filter_array = "<br />_________________________________________<br /><strong>" . __( 'Action and Filter Function Array:', WP_HOOK_PLUGIN_NAME ) . "</strong><br /><br />";
			
			echo $wp_hook_sniffer_wp_filter_array;
			
			foreach ( (array)$wp_filter as $key => $value ) {
				echo '<pre>';
				echo '<strong>' . $key . ': </strong><br />';
				print_r( $value );
				echo '</pre><br />';
			}
			
			// Uncomment below and then comment above to see unformatted array output
			/*
			print_r( $wp_filter );
			echo "<br />";
			*/
		}
	}
	
	
	/**
	 * Action Event Firing Order Output
	 *
	 * Output the contents of the $wp_actions array, the array that holds the 
	 * sequential listing of all the do_action events that need to be processed.
	 */
	if( $wp_hook_sniffer_options_set[ 'output' ][ 'action_event_order' ] == true ) {
		
		if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
			// send output to text file
			$wp_hook_sniffer_wp_actions_array = "\n_________________________________________\n" . __( 'Action Event Firing Order:', WP_HOOK_PLUGIN_NAME ) . "\n\n";
		
			$wp_hook_sniffer_wp_actions_array .= print_r( $wp_actions, true );
			$fh = fopen( $wp_hook_sniff_path_file, "at" ) or die( "can't open file" );
			fwrite( $fh, $wp_hook_sniffer_wp_actions_array );
			fclose( $fh );
		} else {
			$wp_hook_sniffer_wp_actions_array = "<br />_________________________________________<br /><strong>" . __( 'Action Event Firing Order:', WP_HOOK_PLUGIN_NAME ) . "</strong><br /><br />";
			
			echo $wp_hook_sniffer_wp_actions_array;
			print_r( $wp_actions );
			echo "<br />";
		}
	}
	
	
	/**
	 * Action Event Firing Sequence Output
	 *
	 * Output the contents of the $wp_hook_sniff_action_firing_sequence array, the array that holds
	 * the sequential listing of do_action events with their corresponding fired
	 * action function(s).
	 */
	if( $wp_hook_sniffer_options_set[ 'output' ][ 'action_events' ] == true ) {
		
		if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
			$wp_hook_sniffer_action_fired_array_element = "\n_________________________________________\n" . __( 'Action Event Firing Sequence:', WP_HOOK_PLUGIN_NAME ) . "\n\n";
		} else {
			$wp_hook_sniffer_action_fired_array_element = "<br />_________________________________________<br /><strong>" . __( 'Action Event Firing Sequence:', WP_HOOK_PLUGIN_NAME ) . "</strong><br /><br />";
		}

		// List only those action events that have added actions that fired
		foreach( (array)$wp_hook_sniff_action_firing_sequence as $key => $value ) {
			
			if( strpos( $value, "Action event has no added actions" ) !== false ) {
				// Element contains no fired actions
				
			} else {
				// Element contains action that fired
				
				if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
					// send output to text file
					$wp_hook_sniffer_action_fired_array_element .= "{$value}\n";
					$fh = fopen( $wp_hook_sniff_path_file, "at" ) or die( "can't open file" );
					fwrite( $fh, $wp_hook_sniffer_action_fired_array_element );
					fclose( $fh );
				} else {
					$wp_hook_sniffer_action_fired_array_element .= "{$value}<br />";
					echo $wp_hook_sniffer_action_fired_array_element;
				}
				
				// reset variable for next element content
				$wp_hook_sniffer_action_fired_array_element = "";
			}
		}	
	}
	
	
	/**
	 * Filter Event Firing Sequence Output
	 *
	 * Output the contents of the $wp_hook_sniff_filter_firing_sequence array, the array that holds
	 * the sequential listing of apply_filters events with their corresponding fired
	 * filter function(s).
	 */
	if( $wp_hook_sniffer_options_set[ 'output' ][ 'filter_events' ] == true ) {
		
		if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
			$wp_hook_sniffer_filter_fired_array_element = "\n_________________________________________\n" . __( 'Filter Event Firing Sequence:', WP_HOOK_PLUGIN_NAME ) . "\n\n";
		} else {
			$wp_hook_sniffer_filter_fired_array_element = "<br />_________________________________________<br /><strong>" . __( 'Filter Event Firing Sequence:', WP_HOOK_PLUGIN_NAME ) . "</strong><br /><br />";
		}
		
		// List only those action events that have added actions that fired
		foreach( (array)$wp_hook_sniff_filter_firing_sequence as $key => $value ) {
	
			if( strpos( $value, "Filter event has no added filters" ) !== false ) {
				// Element contains no fired actions
			} else {
				// Element contains action that fired
				
				if( $wp_hook_sniffer_options_set[ 'screen' ] == 0 ) {
					// send output to text file
					$wp_hook_sniffer_filter_fired_array_element .= $value . "\n";
					$fh = fopen( $wp_hook_sniff_path_file, "at" ) or die( "can't open file" );
					fwrite( $fh, $wp_hook_sniffer_filter_fired_array_element );
					fclose( $fh );
				} else {
					$wp_hook_sniffer_filter_fired_array_element .= $value . "<br />";
					echo $wp_hook_sniffer_filter_fired_array_element;
				}
			
				// reset variable for next element content
				$wp_hook_sniffer_filter_fired_array_element = "";
			}		
		}
	}
	
	do_action( 'wp_hook_sniff_after_output_hook_info' );

}
add_action( 'shutdown', 'wp_hook_sniff_output_hook_info' );

?>